# config
to read config files using oslo_config
In this module - register_opts is the entry point function
config files will posses the model as defined by the opts parameter passed into filename of register_opts function

